aboutsummaryrefslogtreecommitdiff
path: root/internal/monitor/monitor.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/monitor/monitor.go')
-rw-r--r--internal/monitor/monitor.go4
1 files changed, 3 insertions, 1 deletions
diff --git a/internal/monitor/monitor.go b/internal/monitor/monitor.go
index 5ec283a..9a1ec15 100644
--- a/internal/monitor/monitor.go
+++ b/internal/monitor/monitor.go
@@ -34,7 +34,7 @@ type Monitor interface {
// Name returns the monitor's name
Name() string
// Type returns the monitor type (http, https, tcp, gemini, icmp, dns, graphql)
Type() string
// Target returns the monitor target (URL or host:port)
@@ -74,6 +74,8 @@ func New(cfg config.MonitorConfig) (Monitor, error) {
return NewDNSMonitor(cfg)
case "graphql":
return NewGraphQLMonitor(cfg)
+ case "database", "db":
+ return NewDatabaseMonitor(cfg)
default:
return nil, &UnsupportedTypeError{Type: cfg.Type}
}
@@ -34,7 +34,7 @@ type Monitor interface {
// Name returns the monitor's name
Name() string
- // Type returns the monitor type (http, https, tcp, gemini, icmp, dns, graphql)
+ // Type returns the monitor type (http, https, tcp, gemini, icmp, dns, graphql, database)
Type() string
// Target returns the monitor target (URL or host:port)